==> cxxtools_2.2.1.orig.tar.gz: cxxtools-2.2.1/include/cxxtools/semaphore.h <==
/*
 * Copyright (C) 2005 by Marc Boris Duerner
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef cxxtools_Semaphore_h
#define cxxtools_Semaphore_h

#include <cxxtools/api.h>
#include <cxxtools/noncopyable.h>

namespace cxxtools {

class CXXTOOLS_API Semaphore : private NonCopyable
{
    friend class SemaphoreImpl;

    public:
        //! @brief Construct with initial count
        Semaphore(unsigned int initial = 0);

        //! @brief Destructor. Does not signal...
        ~Semaphore();

        //! @brief Wait for the semaphore to become signaled
        Semaphore& wait();

        //! @brief Non-blocking wait
        bool tryWait();

        //! @brief Signal the semaphore
        Semaphore& post();

    private:
        //! @internal @brief Implementation
        class SemaphoreImpl* _impl;
};

} // !namespace cxxtools

#endif

==> cxxtools_3.0.0.orig.tar.gz: cxxtools-3.0/include/cxxtools/semaphore.h <==
/*
 * Copyright (C) 2005 by Marc Boris Duerner
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef cxxtools_Semaphore_h
#define cxxtools_Semaphore_h


namespace cxxtools {

class Semaphore
{
        friend class SemaphoreImpl;

#if __cplusplus >= 201103L
        Semaphore(const Semaphore&) = delete;
        Semaphore& operator=(const Semaphore&) = delete;
#else
        Semaphore(const Semaphore&) { }
        Semaphore& operator=(const Semaphore&) { return *this; }
#endif

    public:
        //! @brief Construct with initial count
        explicit Semaphore(unsigned int initial = 0);

        //! @brief Destructor. Does not signal...
        ~Semaphore();

        //! @brief Wait for the semaphore to become signaled
        Semaphore& wait();

        //! @brief Non-blocking wait
        bool tryWait();

        //! @brief Signal the semaphore
        Semaphore& post();

    private:
        //! @internal @brief Implementation
        class SemaphoreImpl* _impl;
};

} // !namespace cxxtools

#endif
